==> mongodb-5.0.31.gh.tar.gz: mongo-r5.0.31/src/mongo/db/fts/stemmer_test.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */


#include "mongo/unittest/unittest.h"

#include "mongo/db/fts/fts_spec.h"
#include "mongo/db/fts/stemmer.h"

namespace mongo {
namespace fts {

namespace {
const FTSLanguage* languageEnglishV2() {
    return &FTSLanguage::make("english", TEXT_INDEX_VERSION_2);
}
const FTSLanguage* languagePorterV1() {
    return &FTSLanguage::make("porter", TEXT_INDEX_VERSION_1);
}
}  // namespace

TEST(English, Stemmer1) {
    Stemmer s(languageEnglishV2());
    ASSERT_EQUALS("run", s.stem("running"));
    ASSERT_EQUALS("Run", s.stem("Running"));
}

TEST(English, Caps) {
    Stemmer s(languagePorterV1());
    ASSERT_EQUALS("unit", s.stem("united"));
    ASSERT_EQUALS("Unite", s.stem("United"));
}
}  // namespace fts
}  // namespace mongo

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/fts/stemmer_test.cpp <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */


#include "mongo/db/fts/fts_util.h"
#include "mongo/db/fts/stemmer.h"
#include "mongo/unittest/assert.h"
#include "mongo/unittest/framework.h"

namespace mongo {
namespace fts {

namespace {
const FTSLanguage* languageEnglishV2() {
    return &FTSLanguage::make("english", TEXT_INDEX_VERSION_2);
}
const FTSLanguage* languagePorterV1() {
    return &FTSLanguage::make("porter", TEXT_INDEX_VERSION_1);
}
}  // namespace

TEST(English, Stemmer1) {
    Stemmer s(languageEnglishV2());
    ASSERT_EQUALS("run", s.stem("running"));
    ASSERT_EQUALS("Run", s.stem("Running"));
}

TEST(English, Caps) {
    Stemmer s(languagePorterV1());
    ASSERT_EQUALS("unit", s.stem("united"));
    ASSERT_EQUALS("Unite", s.stem("United"));
}
}  // namespace fts
}  // namespace mongo
